@@ -25,7 +25,6 @@ import shutil
 import sys
 import tempfile
 import urllib2
-from subprocess import call
 
 EZ_SETUP = 'http://peak.telecommunity.com/dist/ez_setup.py'
 eggs_folder = os.path.join(os.path.abspath(os.curdir), 'eggs')
@@ -33,6 +32,11 @@ if not os.path.exists(eggs_folder):
     os.mkdir(eggs_folder)
 sys.path.insert(0, eggs_folder)
 
+downloads_folder = os.path.join(os.path.abspath(os.curdir), 'downloads')
+if not os.path.exists(downloads_folder):
+    os.mkdir(downloads_folder)
+sys.path.insert(0, downloads_folder)
+
 def _import(egg_name):
     mod = __import__(egg_name)
     egg_dir = os.path.dirname(mod.__file__)
@@ -44,7 +48,12 @@ def _import(egg_name):
         if len(path_) > 0:
             path_ = path_[0]
             folder_name = os.path.split(path_)[-1]
-            shutil.copytree(path_, os.path.join(eggs_folder, folder_name))
+            target = os.path.join(eggs_folder, folder_name)
+            if target.lower() == path_.lower():
+                return 
+            if os.path.exists(target):
+                shutil.rmtree(target)
+            shutil.copytree(path_, target)
 
 def _extract_path(egg_name, folder=eggs_folder):
     egg = glob.glob(os.path.join(folder, '%s-*' % egg_name))
@@ -71,13 +80,8 @@ def link_egg(working_set, egg_name, required=True):
             if sys.platform == 'win32':
                 cmd = '"%s"' % cmd # work around spawn lamosity on windows
 
-            retcode = call([sys.executable, '-c', cmd, '-mqNxd', 
-                            eggs_folder, egg_name])
+            print os.system("%s -c %s -mqNxd %s %s" % (sys.executable, cmd, eggs_folder, egg_name))
 
-            if retcode != 0:
-                print 'Could not find %s in eggs, aborting' % egg_name
-                sys.exit(1)
-                
             # retrying import
             working_set.add_entry(egg_name)
             working_set.require(egg_name)
